pm4py.statistics.performance\_spectrum package
==============================================

Module contents
---------------

.. automodule:: pm4py.statistics.performance_spectrum
   :members:
   :undoc-members:
   :show-inheritance:
